@@ -18,12 +18,13 @@ import sys
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 
+from designate.central import service as central_service
 import designate.conf
+from designate import heartbeat_emitter
 from designate import hookpoints
 from designate import service
 from designate import utils
 from designate import version
-from designate.central import service as central_service
 
 
 CONF = designate.conf.CONF
@@ -38,7 +39,8 @@ def main():
     hookpoints.log_hook_setup()
 
     server = central_service.Service()
-    heartbeat = service.Heartbeat(server.service_name, rpc_api=server)
+    heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name,
+                                                        rpc_api=server)
     service.serve(server, workers=CONF['service:central'].workers)
     heartbeat.start()
     service.wait()
